@@ -49,16 +49,14 @@ def main(args):
         print "Installing associated tools..."
         install_tools(gemini["fab"], cbl["tool_fabfile"], fabricrc)
     os.chdir(work_dir)
-    if args.install_data:
-        print "Installing gemini data..."
-        install_data(gemini["python"], gemini["data_script"], args.datadir)
+    install_data(gemini["python"], gemini["data_script"], args)
     os.chdir(work_dir)
     test_script = install_testbase(args.datadir, remotes["gemini"])
     print "Finished: gemini, tools and data installed"
     print " Tools installed in:\n  %s" % args.tooldir
     print " Data installed in:\n  %s" % args.datadir
     print " Run tests with:\n  cd %s && bash %s" % (os.path.dirname(test_script),
-os.path.basename(test_script))
+                                                    os.path.basename(test_script))
     print " NOTE: be sure to add %s/bin to your PATH." % args.tooldir
 
     shutil.rmtree(work_dir)
@@ -70,7 +68,10 @@ def install_gemini(anaconda, remotes, datadir, tooldir, use_sudo):
     try:
         subprocess.check_call([anaconda["easy_install"], "--upgrade", "distribute"])
     except subprocess.CalledProcessError:
-        subprocess.check_call([anaconda["pip"], "install", "--upgrade", "distribute"])
+        try:
+            subprocess.check_call([anaconda["pip"], "install", "--upgrade", "distribute"])
+        except subprocess.CalledProcessError:
+            pass
     # Ensure latest version of fabric for running CloudBioLinux
     subprocess.check_call([anaconda["pip"], "install", "fabric>=1.7.0"])
     # Install problem dependency separately: bx-python
@@ -119,10 +120,8 @@ def install_anaconda_python(args, remotes):
         url = remotes["anaconda"] % ("MacOSX" if distribution == "macosx" else "Linux")
         if not os.path.exists(os.path.basename(url)):
             subprocess.check_call(["wget", url])
-        #subprocess.check_call("LC_ALL=C sed -ie 's/more /cat  /' %s" % os.path.basename(url),
-        #                      shell=True)
-        subprocess.check_call("echo -e '\nyes\n%s\nno\n' | bash %s" %
-                              (anaconda_dir, os.path.basename(url)), shell=True)
+        subprocess.check_call("bash %s -b -p %s" %
+                              (os.path.basename(url), anaconda_dir), shell=True)
     return {"conda": conda,
             "pip": os.path.join(bindir, "pip"),
             "easy_install": os.path.join(bindir, "easy_install"),
@@ -155,10 +154,16 @@ def install_tools(fab_cmd, fabfile, fabricrc):
            "install_biolinux:target=custom,flavor=%s" % flavor_dir]
     subprocess.check_call(cmd)
 
-def install_data(python_cmd, data_script, datadir):
+def install_data(python_cmd, data_script, args):
     """Install biological data used by gemini.
     """
-    subprocess.check_call([python_cmd, data_script, datadir])
+    data_dir = os.path.join(args.datadir, "gemini_data") if args.sharedpy else args.datadir
+    cmd = [python_cmd, data_script, data_dir]
+    if args.install_data:
+        print "Installing gemini data..."
+    else:
+        cmd.append("--nodata")
+    subprocess.check_call(cmd)
 
 def install_testbase(datadir, repo):
     """Clone or update gemini code so we have the latest test suite.
@@ -225,10 +230,13 @@ def check_dependencies():
                      ("wget", "http://www.gnu.org/software/wget/"),
                      ("curl", "http://curl.haxx.se/")]:
         try:
-            subprocess.check_call([cmd, "--version"], stdout=subprocess.PIPE, stderr=subprocess.STDOUT)
-            print " %s found" % cmd
+            retcode = subprocess.call([cmd, "--version"], stdout=subprocess.PIPE, stderr=subprocess.STDOUT)
         except OSError:
+            retcode = 127
+        if retcode == 127:
             raise OSError("gemini requires %s (%s)" % (cmd, url))
+        else:
+            print " %s found" % cmd
 
 if __name__ == "__main__":
     parser = argparse.ArgumentParser(description="Automated installer for gemini framework.")
@@ -242,6 +250,9 @@ if __name__ == "__main__":
                         dest="install_tools", action="store_false", default=True)
     parser.add_argument("--nodata", help="Do not install data dependencies",
                         dest="install_data", action="store_false", default=True)
+    parser.add_argument("--sharedpy", help=("Indicate we share an Anaconda Python directory with "
+                                            "another project. Creates unique gemini data directory."),
+                        action="store_true", default=False)
     if len(sys.argv) == 1:
         parser.print_help()
     else:
